<?php

namespace Litecms\Service\Http\Controllers\Api;

use App\Http\Controllers\Api\AdminController as BaseController;
use Litecms\Service\Http\Requests\ServiceRequest;
use Litecms\Service\Interfaces\ServiceRepositoryInterface;
use Litecms\Service\Models\Service;

/**
 * Admin API controller class.
 */
class ServiceAdminController extends BaseController
{
    /**
     * Initialize service controller.
     *
     * @param type ServiceRepositoryInterface $service
     *
     * @return type
     */
    public function __construct(ServiceRepositoryInterface $service)
    {
        $this->repository = $service;
        parent::__construct();
    }

    /**
     * Display a list of service.
     *
     * @return json
     */
    public function index(ServiceRequest $request)
    {
        $services  = $this->repository
            ->setPresenter('\\Litecms\\Service\\Repositories\\Presenter\\ServiceListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $services['code'] = 2000;
        return response()->json($services) 
                         ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display service.
     *
     * @param Request $request
     * @param Model   Service
     *
     * @return Json
     */
    public function show(ServiceRequest $request, Service $service)
    {
        $service         = $service->presenter();
        $service['code'] = 2001;
        return response()->json($service)
                         ->setStatusCode(200, 'SHOW_SUCCESS');;

    }

    /**
     * Show the form for creating a new service.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(ServiceRequest $request, Service $service)
    {
        $service         = $service->presenter();
        $service['code'] = 2002;
        return response()->json($service)
                         ->setStatusCode(200, 'CREATE_SUCCESS');

    }

    /**
     * Create new service.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(ServiceRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $service          = $this->repository->create($attributes);
            $service          = $service->presenter();
            $service['code']  = 2004;

            return response()->json($service)
                             ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
        }
    }

    /**
     * Show service for editing.
     *
     * @param Request $request
     * @param Model   $service
     *
     * @return json
     */
    public function edit(ServiceRequest $request, Service $service)
    {
        $service         = $service->presenter();
        $service['code'] = 2003;
        return response()-> json($service)
                        ->setStatusCode(200, 'EDIT_SUCCESS');;
    }

    /**
     * Update the service.
     *
     * @param Request $request
     * @param Model   $service
     *
     * @return json
     */
    public function update(ServiceRequest $request, Service $service)
    {
        try {

            $attributes = $request->all();

            $service->update($attributes);
            $service         = $service->presenter();
            $service['code'] = 2005;

            return response()->json($service)
                             ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the service.
     *
     * @param Request $request
     * @param Model   $service
     *
     * @return json
     */
    public function destroy(ServiceRequest $request, Service $service)
    {
        try {
            $t = $service->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('service::service.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
