<?php

namespace Litecms\Service\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Litecms\Service\Interfaces\ServiceRepositoryInterface;
use Litecms\Service\Repositories\Presenter\ServiceItemTransformer;

/**
 * Pubic API controller class.
 */
class ServicePublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Litecms\Service\Interfaces\ServiceRepositoryInterface $service
     *
     * @return type
     */
    public function __construct(ServiceRepositoryInterface $service)
    {
        $this->repository = $service;
        parent::__construct();
    }

    /**
     * Show service's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $services = $this->repository
            ->setPresenter('\\Litecms\\Service\\Repositories\\Presenter\\ServiceListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $services['code'] = 2000;
        return response()->json($services)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show service.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $service = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($service)) {
            $service         = $this->itemPresenter($module, new ServiceItemTransformer);
            $service['code'] = 2001;
            return response()->json($service)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
