<?php

namespace Litecms\Service\Http\Controllers;
use Litepie\Service\Http\Requests\ServiceRequest;
use Litepie\Service\Models\Service;

trait ServiceWorkflow {
	
    /**
     * Workflow controller function for service.
     *
     * @param Model   $service
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(ServiceRequest $request, Service $service, $step)
    {

        try {

            $service->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('service::service.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/service/service/' . $service->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/service/service/' . $service->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for service.
     *
     * @param Model   $service
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Service $service, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $service->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('service::service.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('service::admin.service.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('service::admin.service.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('service::admin.service.message', $data)->render();

        }

    }
}