<?php

namespace Litecms\Service\Policies;

use App\User;
use Litecms\Service\Models\Service;

class ServicePolicy
{

    /**
     * Determine if the given user can view the service.
     *
     * @param User $user
     * @param Service $service
     *
     * @return bool
     */
    public function view(User $user, Service $service)
    {
        if ($user->canDo('service.service.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $service->user_id;
    }

    /**
     * Determine if the given user can create a service.
     *
     * @param User $user
     * @param Service $service
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('service.service.create');
    }

    /**
     * Determine if the given user can update the given service.
     *
     * @param User $user
     * @param Service $service
     *
     * @return bool
     */
    public function update(User $user, Service $service)
    {
        if ($user->canDo('service.service.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $service->user_id;
    }

    /**
     * Determine if the given user can delete the given service.
     *
     * @param User $user
     * @param Service $service
     *
     * @return bool
     */
    public function destroy(User $user, Service $service)
    {
        if ($user->canDo('service.service.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $service->user_id;
    }

    /**
     * Determine if the given user can verify the given service.
     *
     * @param User $user
     * @param Service $service
     *
     * @return bool
     */
    public function verify(User $user, Service $service)
    {
        if ($user->canDo('service.service.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('service.service.verify') 
        && $user->is('manager')
        && $service->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given service.
     *
     * @param User $user
     * @param Service $service
     *
     * @return bool
     */
    public function approve(User $user, Service $service)
    {
        if ($user->canDo('service.service.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
