<?php

namespace Litecms\Service\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Litecms\Service\Models\Service;

class ServiceAction
{
    /**
     * Perform the complete action.
     *
     * @param Service $service
     *
     * @return Service
     */
    public function complete(Service $service)
    {
        try {
            $service->status = 'complete';
            return $service->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Service $service
     *
     * @return Service
     */public function verify(Service $service)
    {
        try {
            $service->status = 'verify';
            return $service->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Service $service
     *
     * @return Service
     */public function approve(Service $service)
    {
        try {
            $service->status = 'approve';
            return $service->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Service $service
     *
     * @return Service
     */public function publish(Service $service)
    {
        try {
            $service->status = 'publish';
            return $service->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Service $service
     *
     * @return Service
     */
    public function archive(Service $service)
    {
        try {
            $service->status = 'archive';
            return $service->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Service $service
     *
     * @return Service
     */
    public function unpublish(Service $service)
    {
        try {
            $service->status = 'unpublish';
            return $service->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
